@@ -125,24 +125,24 @@ class ConfigurationService(object):
         self.opts = opts
         self.parser = parser
 
-    def get(self, name, prefix=None):
+    def get(self, name, domain=None):
         """ Return the value of a configuration option for a given key.
             'name' is either a full dotted name or added to a dotted
-             prefix.
+             domain.
         """
-        OL = util.OptionLookup(self.opts, prefix=prefix)
+        OL = util.OptionLookup(self.opts, domain=domain)
         return OL.get(name)
 
     def getConfiguration(self):
         """ Return all configuration entries as dict """
         return self.opts.__dict__.copy() 
 
-    def getConfigurationForPrefix(self, prefix):
-        """ Return all configuration entries as dict for a given prefix"""
+    def getConfigurationForDomain(self, domain):
+        """ Return all configuration entries as dict for a given domain"""
         opts = self.getConfiguration().copy()
         for opt in opts.keys():
-            opt_prefix, opt_key = opt.rsplit('.' , 1)
-            if opt_prefix != prefix:
+            opt_domain, opt_key = opt.rsplit('.' , 1)
+            if opt_domain != domain:
                 del opts[opt]
         return opts
 
