@@ -36,10 +36,8 @@ class ConfigurationTests(TestCase):
         opts = parser.parse()
         OL = OptionLookup(opts)
         self.assertEqual(OL.get('cms.path'), '/foo/bar') 
-        self.assertEqual(OL.get('cms.checkout_path'), None)
+        self.assertRaises(KeyError, OL.get, 'cms.checkout_path')
         self.assertEqual(OL.get('cms.port'), 42)
-        self.assertEqual(OL.get('cms.databases.db1'), None)
-        self.assertEqual(OL.get('cms.databases.db2'), None)
 
     def testOptionLookupWithConfigurationFile(self):
         parser = self._generateParser('model') 
@@ -50,9 +48,8 @@ class ConfigurationTests(TestCase):
         self.assertEqual(OL.get('cms.checkout_path'), '/foo/bar')
         self.assertEqual(OL.get('cms.port'), 777)
         self.assertEqual(OL.get('cms.databases.db1'), 'n/a')
-        self.assertEqual(OL.get('cms.databases.db2'), None)
 
-    def testOptionLookupWithConfigurationFileWithPrefix(self):
+    def testOptionLookupWithConfigurationFileWithDomain(self):
         parser = self._generateParser('model') 
         parser.add_file(os.path.join(dirname, 'example-config.ini'))
         opts = parser.parse()
@@ -61,11 +58,9 @@ class ConfigurationTests(TestCase):
         self.assertEqual(OL.get('checkout_path'), '/foo/bar')
         self.assertEqual(OL.get('port'), 777)
         self.assertEqual(OL.get('databases.db1'), 'n/a')
-        self.assertEqual(OL.get('databases.db2'), None)
-        self.assertEqual(OL.has('databases.db2'), True)
         self.assertEqual(OL.has('gibt.es.nicht'), False)
 
-    def testOptionLookupWithConfigurationFileWithPrefixAndFullName(self):
+    def testOptionLookupWithConfigurationFileWithDomainAndFullName(self):
         parser = self._generateParser('model') 
         parser.add_file(os.path.join(dirname, 'example-config.ini'))
         opts = parser.parse()
@@ -74,8 +69,6 @@ class ConfigurationTests(TestCase):
         self.assertEqual(OL.get('cms.checkout_path'), '/foo/bar')
         self.assertEqual(OL.get('cms.port'), 777)
         self.assertEqual(OL.get('cms.databases.db1'), 'n/a')
-        self.assertEqual(OL.get('cms.databases.db2'), None)
-        self.assertEqual(OL.has('cms.databases.db2'), True)
         self.assertEqual(OL.has('cms.gibt.es.nicht'), False)
 
 
@@ -84,7 +77,7 @@ class ConfigurationTests(TestCase):
         parser.add_file(os.path.join(dirname, 'example-config.ini'))
         opts = parser.parse()
         OL = OptionLookup(opts)
-        self.assertRaises(ValueError, OL.get,'gibt.es.nicht')
+        self.assertRaises(KeyError, OL.get,'gibt.es.nicht')
 
 
 class UtilTests(TestCase):
