@@ -9,6 +9,11 @@ import os
 import cfgparse
 import ConfigParser
 
+class Marker(object):
+    pass
+
+DEFAULT_MARKER = Marker
+
 
 def generateParser(name, LOG=None, parser=None):
     """ Generate a configuration parser for all modules described.
@@ -55,7 +60,7 @@ def parseModel(filename, parser, LOG=None):
         for option in CP.options(section):
 
             value = CP.get(section, option).strip()
-            default = None
+            default = DEFAULT_MARKER
             type = 'string'
             if value:
                 if ',' in value:
@@ -77,9 +82,9 @@ def parseModel(filename, parser, LOG=None):
 class OptionLookup(object):
     """ Lookup values of configurations by a dotted name """
 
-    def __init__(self, opts, prefix=None):
+    def __init__(self, opts, domain=None):
         self.opts = opts
-        self.prefix = prefix
+        self.domain = domain
         # Optimization: has() should have 0(1) running time
         self.known_opts = dict()
         for k in self.opts.__dict__.keys():
@@ -87,12 +92,16 @@ class OptionLookup(object):
                 self.known_opts[k] = True
 
     def get(self, name, expand_env=False):
-        if self.prefix and not name.startswith(self.prefix):
-            name = '%s.%s' % (self.prefix, name)
+        if self.domain and not name.startswith(self.domain):
+            name = '%s.%s' % (self.domain, name)
         try:
             v = getattr(self.opts, name)
         except AttributeError:
-            raise ValueError('Unknown key: %s' % name)
+            raise KeyError('Unknown key: %s' % name)
+
+        if v is DEFAULT_MARKER:
+            raise KeyError('Neither a default nor a configuration ' + 
+                           'found for Key: %s' % name)
 
         if expand_env:
             return os.path.expandvars(v)
@@ -100,8 +109,8 @@ class OptionLookup(object):
             return v
 
     def has(self, name):
-        if self.prefix and not name.startswith(self.prefix):
-            name = '%s.%s' % (self.prefix, name)
+        if self.domain and not name.startswith(self.domain):
+            name = '%s.%s' % (self.domain, name)
         return self.known_opts.has_key(name)
 
 
